#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['jeepney',
 'jeepney.integrate',
 'jeepney.integrate.tests',
 'jeepney.io',
 'jeepney.io.tests',
 'jeepney.tests']

package_data = \
{'': ['*']}

extras_require = \
{'test': ['pytest', 'pytest-trio', 'pytest-asyncio', 'testpath', 'trio']}

setup(name='jeepney',
      version='0.5.0',
      description='Low-level, pure Python DBus protocol wrapper.',
      author='Thomas Kluyver',
      author_email='thomas@kluyver.me.uk',
      url='https://gitlab.com/takluyver/jeepney',
      packages=packages,
      package_data=package_data,
      extras_require=extras_require,
      python_requires='>=3.6',
     )
